@@ -8,9 +8,9 @@
 #include "ipv6setting.h"
 #include "ipv6setting_p.h"
 
-#include "utils.h"
-#include "generictypes.h"
 #include "../ipconfig.h"
+#include "generictypes.h"
+#include "utils.h"
 
 #include <arpa/inet.h>
 
@@ -27,12 +27,14 @@ NetworkManager::Ipv6SettingPrivate::Ipv6SettingPrivate()
     , addressGenMode(NetworkManager::Ipv6Setting::StablePrivacy)
     , dhcpTimeout(0)
     , routeTable(0)
-{ }
+{
+}
 
 NetworkManager::Ipv6Setting::Ipv6Setting()
     : Setting(Setting::Ipv6)
     , d_ptr(new Ipv6SettingPrivate())
-{ }
+{
+}
 
 NetworkManager::Ipv6Setting::Ipv6Setting(const Ptr &other)
     : Setting(other)
@@ -121,14 +123,14 @@ void NetworkManager::Ipv6Setting::setAddresses(const QList<IpAddress> ipv6addres
     d->addresses = ipv6addresses;
 }
 
-QList< NetworkManager::IpAddress > NetworkManager::Ipv6Setting::addresses() const
+QList<NetworkManager::IpAddress> NetworkManager::Ipv6Setting::addresses() const
 {
     Q_D(const Ipv6Setting);
 
     return d->addresses;
 }
 
-void NetworkManager::Ipv6Setting::setRoutes(const QList< NetworkManager::IpRoute > ipv6routes)
+void NetworkManager::Ipv6Setting::setRoutes(const QList<NetworkManager::IpRoute> ipv6routes)
 {
     Q_D(Ipv6Setting);
 
@@ -381,6 +383,8 @@ void NetworkManager::Ipv6Setting::fromMap(const QVariantMap &setting)
             setMethod(Manual);
         } else if (methodType.toLower() == QLatin1String(NMQT_SETTING_IP6_CONFIG_METHOD_IGNORE)) {
             setMethod(Ignored);
+        } else if (methodType.toLower() == QLatin1String(NMQT_SETTING_IP6_CONFIG_METHOD_DISABLED)) {
+            setMethod(ConfigDisabled);
         } else {
             setMethod(Automatic);
         }
@@ -390,13 +394,13 @@ void NetworkManager::Ipv6Setting::fromMap(const QVariantMap &setting)
         QList<QHostAddress> dbusDns;
         QList<QByteArray> temp;
         if (setting.value(QLatin1String(NMQT_SETTING_IP6_CONFIG_DNS)).canConvert<QDBusArgument>()) {
-            QDBusArgument dnsArg = setting.value(QLatin1String(NMQT_SETTING_IP6_CONFIG_DNS)).value< QDBusArgument>();
-            temp = qdbus_cast<QList<QByteArray> >(dnsArg);
+            QDBusArgument dnsArg = setting.value(QLatin1String(NMQT_SETTING_IP6_CONFIG_DNS)).value<QDBusArgument>();
+            temp = qdbus_cast<QList<QByteArray>>(dnsArg);
         } else {
-            temp = setting.value(QLatin1String(NMQT_SETTING_IP6_CONFIG_DNS)).value<QList<QByteArray> >();
+            temp = setting.value(QLatin1String(NMQT_SETTING_IP6_CONFIG_DNS)).value<QList<QByteArray>>();
         }
 
-        Q_FOREACH (const QByteArray & utmp, temp) {
+        for (const QByteArray &utmp : std::as_const(temp)) {
             dbusDns << ipv6AddressAsHostAddress(utmp);
         }
 
@@ -410,14 +414,14 @@ void NetworkManager::Ipv6Setting::fromMap(const QVariantMap &setting)
     if (setting.contains(QLatin1String(NMQT_SETTING_IP6_CONFIG_ADDRESSES))) {
         QList<IpV6DBusAddress> temp;
         if (setting.value(QLatin1String(NMQT_SETTING_IP6_CONFIG_DNS)).canConvert<QDBusArgument>()) {
-            QDBusArgument addressArg = setting.value(QLatin1String(NMQT_SETTING_IP6_CONFIG_ADDRESSES)).value< QDBusArgument>();
-            temp = qdbus_cast<QList<IpV6DBusAddress> >(addressArg);
+            QDBusArgument addressArg = setting.value(QLatin1String(NMQT_SETTING_IP6_CONFIG_ADDRESSES)).value<QDBusArgument>();
+            temp = qdbus_cast<QList<IpV6DBusAddress>>(addressArg);
         } else {
-            temp = setting.value(QLatin1String(NMQT_SETTING_IP6_CONFIG_ADDRESSES)).value<QList<IpV6DBusAddress> >();
+            temp = setting.value(QLatin1String(NMQT_SETTING_IP6_CONFIG_ADDRESSES)).value<QList<IpV6DBusAddress>>();
         }
         QList<NetworkManager::IpAddress> addresses;
 
-        Q_FOREACH (const IpV6DBusAddress & addressMap, temp) {
+        for (const IpV6DBusAddress &addressMap : std::as_const(temp)) {
             if (addressMap.address.isEmpty() || !addressMap.prefix || addressMap.gateway.isEmpty()) {
                 continue;
             }
@@ -439,14 +443,14 @@ void NetworkManager::Ipv6Setting::fromMap(const QVariantMap &setting)
     if (setting.contains(QLatin1String(NMQT_SETTING_IP6_CONFIG_ROUTES))) {
         QList<IpV6DBusRoute> temp;
         if (setting.value(QLatin1String(NMQT_SETTING_IP6_CONFIG_ROUTES)).canConvert<QDBusArgument>()) {
-            QDBusArgument routeArg = setting.value(QLatin1String(NMQT_SETTING_IP6_CONFIG_ROUTES)).value< QDBusArgument>();
-            temp = qdbus_cast<QList<IpV6DBusRoute> >(routeArg);
+            QDBusArgument routeArg = setting.value(QLatin1String(NMQT_SETTING_IP6_CONFIG_ROUTES)).value<QDBusArgument>();
+            temp = qdbus_cast<QList<IpV6DBusRoute>>(routeArg);
         } else {
-            temp = setting.value(QLatin1String(NMQT_SETTING_IP6_CONFIG_ROUTES)).value<QList<IpV6DBusRoute> >();
+            temp = setting.value(QLatin1String(NMQT_SETTING_IP6_CONFIG_ROUTES)).value<QList<IpV6DBusRoute>>();
         }
         QList<NetworkManager::IpRoute> routes;
 
-        Q_FOREACH (const IpV6DBusRoute & routeMap, temp) {
+        for (const IpV6DBusRoute &routeMap : std::as_const(temp)) {
             if (routeMap.destination.isEmpty() || !routeMap.prefix || routeMap.nexthop.isEmpty() || !routeMap.metric) {
                 continue;
             }
@@ -544,11 +548,14 @@ QVariantMap NetworkManager::Ipv6Setting::toMap() const
         setting.insert(QLatin1String(NMQT_SETTING_IP6_CONFIG_METHOD), QLatin1String(NMQT_SETTING_IP6_CONFIG_METHOD_MANUAL));
     } else if (method() == Ignored) {
         setting.insert(QLatin1String(NMQT_SETTING_IP6_CONFIG_METHOD), QLatin1String(NMQT_SETTING_IP6_CONFIG_METHOD_IGNORE));
+    } else if (method() == ConfigDisabled) {
+        setting.insert(QLatin1String(NMQT_SETTING_IP6_CONFIG_METHOD), QLatin1String(NMQT_SETTING_IP6_CONFIG_METHOD_DISABLED));
     }
 
     if (!dns().isEmpty()) {
         QList<QByteArray> dbusDns;
-        Q_FOREACH (const QHostAddress & dns, dns()) {
+        const QList<QHostAddress> dnsList = dns();
+        for (const QHostAddress &dns : dnsList) {
             dbusDns << ipv6AddressFromHostAddress(dns);
         }
         setting.insert(QLatin1String(NMQT_SETTING_IP6_CONFIG_DNS), QVariant::fromValue(dbusDns));
@@ -560,7 +567,8 @@ QVariantMap NetworkManager::Ipv6Setting::toMap() const
 
     if (!addresses().isEmpty()) {
         QList<IpV6DBusAddress> dbusAddresses;
-        Q_FOREACH (const NetworkManager::IpAddress & addr, addresses()) {
+        const QList<NetworkManager::IpAddress> addressesList = addresses();
+        for (const NetworkManager::IpAddress &addr : addressesList) {
             IpV6DBusAddress dbusAddress;
             dbusAddress.address = ipv6AddressFromHostAddress(addr.ip());
             dbusAddress.prefix = addr.prefixLength();
@@ -573,7 +581,8 @@ QVariantMap NetworkManager::Ipv6Setting::toMap() const
 
     if (!routes().isEmpty()) {
         QList<IpV6DBusRoute> dbusRoutes;
-        Q_FOREACH (const NetworkManager::IpRoute & route, routes()) {
+        const QList<NetworkManager::IpRoute> routesList = routes();
+        for (const NetworkManager::IpRoute &route : routesList) {
             IpV6DBusRoute dbusRoute;
             dbusRoute.destination = ipv6AddressFromHostAddress(route.ip());
             dbusRoute.prefix = route.prefixLength();
@@ -585,7 +594,7 @@ QVariantMap NetworkManager::Ipv6Setting::toMap() const
         setting.insert(QLatin1String(NMQT_SETTING_IP6_CONFIG_ROUTES), QVariant::fromValue(dbusRoutes));
     }
 
-    if(routeMetric() >= 0) {
+    if (routeMetric() >= 0) {
         setting.insert(QLatin1String(NMQT_SETTING_IP6_CONFIG_ROUTE_METRIC), routeMetric());
     }
 
@@ -650,23 +659,26 @@ QVariantMap NetworkManager::Ipv6Setting::toMap() const
     return setting;
 }
 
-QDebug NetworkManager::operator <<(QDebug dbg, const NetworkManager::Ipv6Setting &setting)
+QDebug NetworkManager::operator<<(QDebug dbg, const NetworkManager::Ipv6Setting &setting)
 {
     dbg.nospace() << "type: " << setting.typeAsString(setting.type()) << '\n';
     dbg.nospace() << "initialized: " << !setting.isNull() << '\n';
 
     dbg.nospace() << NMQT_SETTING_IP6_CONFIG_METHOD << ": " << setting.method() << '\n';
     dbg.nospace() << NMQT_SETTING_IP6_CONFIG_DNS << '\n';
-    Q_FOREACH (const QHostAddress & address, setting.dns()) {
+    const QList<QHostAddress> hostAdresses = setting.dns();
+    for (const QHostAddress &address : hostAdresses) {
         dbg.nospace() << address.toString() << '\n';
     }
     dbg.nospace() << NMQT_SETTING_IP6_CONFIG_DNS_SEARCH << ": " << setting.dnsSearch() << '\n';
     dbg.nospace() << NMQT_SETTING_IP6_CONFIG_ADDRESSES << '\n';
-    Q_FOREACH (const NetworkManager::IpAddress & address, setting.addresses()) {
+    const QList<NetworkManager::IpAddress> ipList = setting.addresses();
+    for (const NetworkManager::IpAddress &address : ipList) {
         dbg.nospace() << address.ip().toString() << ": " << address.gateway().toString() << ": " << address.netmask() << '\n';
     }
     dbg.nospace() << NMQT_SETTING_IP6_CONFIG_ROUTES << '\n';
-    Q_FOREACH (const NetworkManager::IpRoute & route, setting.routes()) {
+    const QList<NetworkManager::IpRoute> routesList = setting.routes();
+    for (const NetworkManager::IpRoute &route : routesList) {
         dbg.nospace() << route.ip().toString() << ": " << route.metric() << ": " << route.nextHop().toString() << ": " << route.metric() << '\n';
     }
     dbg.nospace() << NMQT_SETTING_IP6_CONFIG_ROUTE_METRIC << ":" << setting.routeMetric() << '\n';
@@ -683,14 +695,16 @@ QDebug NetworkManager::operator <<(QDebug dbg, const NetworkManager::Ipv6Setting
     dbg.nospace() << NMQT_SETTING_IP6_CONFIG_TOKEN << ": " << setting.token() << '\n';
     dbg.nospace() << NMQT_SETTING_IP6_CONFIG_DNS_OPTIONS << ": " << setting.dnsOptions() << '\n';
     dbg.nospace() << NMQT_SETTING_IP6_CONFIG_ADDRESS_DATA << ": " << '\n';
-    Q_FOREACH (const QVariantMap & addressData, setting.addressData()) {
+    const auto dataList = setting.addressData();
+    for (const QVariantMap &addressData : dataList) {
         QVariantMap::const_iterator i = addressData.constBegin();
         while (i != addressData.constEnd()) {
-        dbg.nospace() << i.key() << ": " << i.value() << '\n';
+            dbg.nospace() << i.key() << ": " << i.value() << '\n';
         }
     }
     dbg.nospace() << NMQT_SETTING_IP6_CONFIG_ROUTE_DATA << ": " << '\n';
-    Q_FOREACH (const QVariantMap & routeData, setting.routeData()) {
+    const auto routeDataList = setting.routeData();
+    for (const QVariantMap &routeData : routeDataList) {
         QVariantMap::const_iterator i = routeData.constBegin();
         while (i != routeData.constEnd()) {
             dbg.nospace() << i.key() << ": " << i.value() << '\n';
