@@ -15,13 +15,12 @@
 #include <libnm/NetworkManager.h>
 #define signals Q_SIGNALS
 
-#include <QVariantMap>
-#include <QStringList>
 #include <QSharedPointer>
+#include <QStringList>
+#include <QVariantMap>
 
 namespace NetworkManager
 {
-
 class SettingPrivate;
 
 /**
@@ -70,21 +69,21 @@ public:
         TeamPort,
         Macsec,
         Dcb,
-        WireGuard
+        WireGuard,
     };
 
     enum SecretFlagType {
         None = 0,
         AgentOwned = 0x01,
         NotSaved = 0x02,
-        NotRequired = 0x04
+        NotRequired = 0x04,
     };
     Q_DECLARE_FLAGS(SecretFlags, SecretFlagType)
 
     enum MacAddressRandomization {
         MacAddressRandomizationDefault = 0,
         MacAddressRandomizationNever,
-        MacAddressRandomizationAlways
+        MacAddressRandomizationAlways,
     };
 
     static QString typeAsString(SettingType type);
