@@ -1,39 +1,22 @@
 /*
-    Copyright 2008,2011 Will Stephenson <wstephenson@kde.org>
-    Copyright 2013 Daniel Nicoletti <dantti12@gmail.com>
-    Copyright 2013 Jan Grulich <jgrulich@redhat.com>
+    SPDX-FileCopyrightText: 2008, 2011 Will Stephenson <wstephenson@kde.org>
+    SPDX-FileCopyrightText: 2013 Daniel Nicoletti <dantti12@gmail.com>
+    SPDX-FileCopyrightText: 2013 Jan Grulich <jgrulich@redhat.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "wirelessdevice.h"
 #include "wirelessdevice_p.h"
 
-#include <nm-version.h>
-#if NM_CHECK_VERSION(1, 0, 0)
+#undef signals
 #include <libnm/NetworkManager.h>
-#else
-#include <libnm-glib/nm-device-wifi.h>
-#endif
+#define signals Q_SIGNALS
 
-#include "accesspoint.h"
 #include "manager_p.h"
 
 #include "nmdebug.h"
+#include "utils.h"
 
 NetworkManager::WirelessDevicePrivate::WirelessDevicePrivate(const QString &path, WirelessDevice *q)
     : DevicePrivate(path, q)
@@ -51,41 +34,28 @@ NetworkManager::WirelessDevice::WirelessDevice(const QString &path, QObject *par
 {
     Q_D(WirelessDevice);
 
-    d->hardwareAddress = d->wirelessIface.hwAddress();
-    d->permanentHardwareAddress = d->wirelessIface.permHwAddress();
-    d->mode = convertOperationMode(d->wirelessIface.mode());
-    d->bitRate = d->wirelessIface.bitrate();
-    d->wirelessCapabilities = convertCapabilities(d->wirelessIface.wirelessCapabilities());
+    qDBusRegisterMetaType<QList<QDBusObjectPath>>();
 
-    qDBusRegisterMetaType<QList<QDBusObjectPath> >();
-
-#if NM_CHECK_VERSION(0, 9, 10)
-    QList <QDBusObjectPath> aps = d->wirelessIface.accessPoints();
-    // qCDebug(NMQT) << "AccessPoint list";
-    Q_FOREACH (const QDBusObjectPath & op, aps) {
-        // qCDebug(NMQT) << "  " << op.path();
-        d->accessPointAdded(op);
-    }
-#else
-    QDBusReply< QList <QDBusObjectPath> > apPathList = d->wirelessIface.GetAccessPoints();
-    // qCDebug(NMQT) << "AccessPoint list";
-    if (apPathList.isValid()) {
-        //qCDebug(NMQT) << "Got device list";
-        QList <QDBusObjectPath> aps = apPathList.value();
-        Q_FOREACH (const QDBusObjectPath & op, aps) {
-            // qCDebug(NMQT) << "  " << op.path();
-            d->accessPointAdded(op);
-        }
-    } else {
-        qCDebug(NMQT) << "Error getting access point list: " << apPathList.error().name() << ": " << apPathList.error().message();
-    }
+#ifdef NMQT_STATIC
+    connect(&d->wirelessIface, &OrgFreedesktopNetworkManagerDeviceWirelessInterface::PropertiesChanged, d, &WirelessDevicePrivate::propertiesChanged);
 #endif
 
-    connect(&d->wirelessIface, &OrgFreedesktopNetworkManagerDeviceWirelessInterface::PropertiesChanged, d, &WirelessDevicePrivate::propertiesChanged);
     connect(&d->wirelessIface, &OrgFreedesktopNetworkManagerDeviceWirelessInterface::AccessPointAdded, d, &WirelessDevicePrivate::accessPointAdded);
     connect(&d->wirelessIface, &OrgFreedesktopNetworkManagerDeviceWirelessInterface::AccessPointRemoved, d, &WirelessDevicePrivate::accessPointRemoved);
 
-    d->activeAccessPoint = findAccessPoint(d->wirelessIface.activeAccessPoint().path());
+    const QList<QDBusObjectPath> aps = d->wirelessIface.accessPoints();
+    // qCDebug(NMQT) << "AccessPoint list";
+    for (const QDBusObjectPath &op : aps) {
+        // qCDebug(NMQT) << "  " << op.path();
+        d->accessPointAdded(op);
+    }
+
+    // Get all WirelessDevices's properties at once
+    QVariantMap initialProperties = NetworkManagerPrivate::retrieveInitialProperties(d->wirelessIface.staticInterfaceName(), path);
+    if (!initialProperties.isEmpty()) {
+        d->propertiesChanged(initialProperties);
+    }
+
 }
 
 NetworkManager::WirelessDevice::~WirelessDevice()
@@ -106,6 +76,7 @@ QStringList NetworkManager::WirelessDevice::accessPoints() const
 QDBusPendingReply<> NetworkManager::WirelessDevice::requestScan(const QVariantMap &options)
 {
     Q_D(WirelessDevice);
+    d->lastRequestScan = QDateTime::currentDateTime();
     return d->wirelessIface.RequestScan(options);
 }
 
@@ -139,6 +110,18 @@ int NetworkManager::WirelessDevice::bitRate() const
     return d->bitRate;
 }
 
+QDateTime NetworkManager::WirelessDevice::lastScan() const
+{
+    Q_D(const WirelessDevice);
+    return d->lastScan;
+}
+
+QDateTime NetworkManager::WirelessDevice::lastRequestScan() const
+{
+    Q_D(const WirelessDevice);
+    return d->lastRequestScan;
+}
+
 NetworkManager::WirelessDevice::Capabilities NetworkManager::WirelessDevice::wirelessCapabilities() const
 {
     Q_D(const WirelessDevice);
@@ -182,7 +165,7 @@ NetworkManager::WirelessNetwork::Ptr NetworkManager::WirelessDevice::findNetwork
 
 void NetworkManager::WirelessDevicePrivate::accessPointAdded(const QDBusObjectPath &accessPoint)
 {
-    //kDebug(1441) << apPath.path();
+    // kDebug(1441) << apPath.path();
     Q_Q(WirelessDevice);
 
     if (!apMap.contains(accessPoint.path())) {
@@ -202,14 +185,13 @@ void NetworkManager::WirelessDevicePrivate::accessPointAdded(const QDBusObjectPa
 
 void NetworkManager::WirelessDevicePrivate::accessPointRemoved(const QDBusObjectPath &accessPoint)
 {
-    //kDebug(1441) << apPath.path();
+    // kDebug(1441) << apPath.path();
     Q_Q(WirelessDevice);
     if (!apMap.contains(accessPoint.path())) {
         qCDebug(NMQT) << "Access point list lookup failed for " << accessPoint.path();
     }
     Q_EMIT q->accessPointDisappeared(accessPoint.path());
     apMap.remove(accessPoint.path());
-
 }
 
 void NetworkManager::WirelessDevicePrivate::removeNetwork(const QString &network)
@@ -245,6 +227,9 @@ void NetworkManager::WirelessDevicePrivate::propertyChanged(const QString &prope
     } else if (property == QLatin1String("WirelessCapabilities")) {
         wirelessCapabilities = q->convertCapabilities(value.toUInt());
         Q_EMIT q->wirelessCapabilitiesChanged(wirelessCapabilities);
+    } else if (property == QLatin1String("LastScan")) {
+        lastScan = NetworkManager::clockBootTimeToDateTime(value.toLongLong());
+        Q_EMIT q->lastScanChanged(lastScan);
     } else if (property == QLatin1String("AccessPoints")) {
         // TODO use this instead AccessPointAdded/Removed signals?
     } else {
